# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DomainAuthConfigArgs',
    'DomainAuthConfigArgsDict',
    'DomainCacheConfigArgs',
    'DomainCacheConfigArgsDict',
    'DomainCertificateConfigArgs',
    'DomainCertificateConfigArgsDict',
    'DomainConfigFunctionArgArgs',
    'DomainConfigFunctionArgArgsDict',
    'DomainHttpHeaderConfigArgs',
    'DomainHttpHeaderConfigArgsDict',
    'DomainNewCertificateConfigArgs',
    'DomainNewCertificateConfigArgsDict',
    'DomainNewSourceArgs',
    'DomainNewSourceArgsDict',
    'DomainPage404ConfigArgs',
    'DomainPage404ConfigArgsDict',
    'DomainParameterFilterConfigArgs',
    'DomainParameterFilterConfigArgsDict',
    'DomainReferConfigArgs',
    'DomainReferConfigArgsDict',
]

MYPY = False

if not MYPY:
    class DomainAuthConfigArgsDict(TypedDict):
        auth_type: NotRequired[pulumi.Input[str]]
        master_key: NotRequired[pulumi.Input[str]]
        slave_key: NotRequired[pulumi.Input[str]]
        timeout: NotRequired[pulumi.Input[int]]
elif False:
    DomainAuthConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainAuthConfigArgs:
    def __init__(__self__, *,
                 auth_type: Optional[pulumi.Input[str]] = None,
                 master_key: Optional[pulumi.Input[str]] = None,
                 slave_key: Optional[pulumi.Input[str]] = None,
                 timeout: Optional[pulumi.Input[int]] = None):
        if auth_type is not None:
            pulumi.set(__self__, "auth_type", auth_type)
        if master_key is not None:
            pulumi.set(__self__, "master_key", master_key)
        if slave_key is not None:
            pulumi.set(__self__, "slave_key", slave_key)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="authType")
    def auth_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "auth_type")

    @auth_type.setter
    def auth_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_type", value)

    @property
    @pulumi.getter(name="masterKey")
    def master_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "master_key")

    @master_key.setter
    def master_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "master_key", value)

    @property
    @pulumi.getter(name="slaveKey")
    def slave_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "slave_key")

    @slave_key.setter
    def slave_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slave_key", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "timeout", value)


if not MYPY:
    class DomainCacheConfigArgsDict(TypedDict):
        cache_content: pulumi.Input[str]
        cache_type: pulumi.Input[str]
        ttl: pulumi.Input[int]
        cache_id: NotRequired[pulumi.Input[str]]
        weight: NotRequired[pulumi.Input[int]]
elif False:
    DomainCacheConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainCacheConfigArgs:
    def __init__(__self__, *,
                 cache_content: pulumi.Input[str],
                 cache_type: pulumi.Input[str],
                 ttl: pulumi.Input[int],
                 cache_id: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None):
        pulumi.set(__self__, "cache_content", cache_content)
        pulumi.set(__self__, "cache_type", cache_type)
        pulumi.set(__self__, "ttl", ttl)
        if cache_id is not None:
            pulumi.set(__self__, "cache_id", cache_id)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter(name="cacheContent")
    def cache_content(self) -> pulumi.Input[str]:
        return pulumi.get(self, "cache_content")

    @cache_content.setter
    def cache_content(self, value: pulumi.Input[str]):
        pulumi.set(self, "cache_content", value)

    @property
    @pulumi.getter(name="cacheType")
    def cache_type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "cache_type")

    @cache_type.setter
    def cache_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "cache_type", value)

    @property
    @pulumi.getter
    def ttl(self) -> pulumi.Input[int]:
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: pulumi.Input[int]):
        pulumi.set(self, "ttl", value)

    @property
    @pulumi.getter(name="cacheId")
    def cache_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cache_id")

    @cache_id.setter
    def cache_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cache_id", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "weight", value)


if not MYPY:
    class DomainCertificateConfigArgsDict(TypedDict):
        private_key: NotRequired[pulumi.Input[str]]
        server_certificate: NotRequired[pulumi.Input[str]]
        server_certificate_status: NotRequired[pulumi.Input[str]]
elif False:
    DomainCertificateConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainCertificateConfigArgs:
    def __init__(__self__, *,
                 private_key: Optional[pulumi.Input[str]] = None,
                 server_certificate: Optional[pulumi.Input[str]] = None,
                 server_certificate_status: Optional[pulumi.Input[str]] = None):
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if server_certificate is not None:
            pulumi.set(__self__, "server_certificate", server_certificate)
        if server_certificate_status is not None:
            pulumi.set(__self__, "server_certificate_status", server_certificate_status)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="serverCertificate")
    def server_certificate(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "server_certificate")

    @server_certificate.setter
    def server_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server_certificate", value)

    @property
    @pulumi.getter(name="serverCertificateStatus")
    def server_certificate_status(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "server_certificate_status")

    @server_certificate_status.setter
    def server_certificate_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server_certificate_status", value)


if not MYPY:
    class DomainConfigFunctionArgArgsDict(TypedDict):
        arg_name: pulumi.Input[str]
        """
        The name of arg.
        """
        arg_value: pulumi.Input[str]
        """
        The value of arg.
        """
elif False:
    DomainConfigFunctionArgArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainConfigFunctionArgArgs:
    def __init__(__self__, *,
                 arg_name: pulumi.Input[str],
                 arg_value: pulumi.Input[str]):
        """
        :param pulumi.Input[str] arg_name: The name of arg.
        :param pulumi.Input[str] arg_value: The value of arg.
        """
        pulumi.set(__self__, "arg_name", arg_name)
        pulumi.set(__self__, "arg_value", arg_value)

    @property
    @pulumi.getter(name="argName")
    def arg_name(self) -> pulumi.Input[str]:
        """
        The name of arg.
        """
        return pulumi.get(self, "arg_name")

    @arg_name.setter
    def arg_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "arg_name", value)

    @property
    @pulumi.getter(name="argValue")
    def arg_value(self) -> pulumi.Input[str]:
        """
        The value of arg.
        """
        return pulumi.get(self, "arg_value")

    @arg_value.setter
    def arg_value(self, value: pulumi.Input[str]):
        pulumi.set(self, "arg_value", value)


if not MYPY:
    class DomainHttpHeaderConfigArgsDict(TypedDict):
        header_key: pulumi.Input[str]
        header_value: pulumi.Input[str]
        header_id: NotRequired[pulumi.Input[str]]
elif False:
    DomainHttpHeaderConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainHttpHeaderConfigArgs:
    def __init__(__self__, *,
                 header_key: pulumi.Input[str],
                 header_value: pulumi.Input[str],
                 header_id: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "header_key", header_key)
        pulumi.set(__self__, "header_value", header_value)
        if header_id is not None:
            pulumi.set(__self__, "header_id", header_id)

    @property
    @pulumi.getter(name="headerKey")
    def header_key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "header_key")

    @header_key.setter
    def header_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "header_key", value)

    @property
    @pulumi.getter(name="headerValue")
    def header_value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "header_value")

    @header_value.setter
    def header_value(self, value: pulumi.Input[str]):
        pulumi.set(self, "header_value", value)

    @property
    @pulumi.getter(name="headerId")
    def header_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "header_id")

    @header_id.setter
    def header_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "header_id", value)


if not MYPY:
    class DomainNewCertificateConfigArgsDict(TypedDict):
        cert_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the certificate. It takes effect only when CertType = cas.
        """
        cert_name: NotRequired[pulumi.Input[str]]
        """
        Certificate name, only flyer names are supported.
        """
        cert_region: NotRequired[pulumi.Input[str]]
        """
        The certificate region, which takes effect only when CertType = cas, supports cn-hangzhou (domestic) and ap-southeast-1 (International), and is cn-hangzhou by default.
        """
        cert_type: NotRequired[pulumi.Input[str]]
        """
        Certificate type. Value:
        - **upload**: upload certificate.
        - **cas**: Cloud Shield certificate.
        - **free**: free certificate.
        > If the certificate type is **cas**, **PrivateKey** does not need to pass parameters.
        """
        force_set: NotRequired[pulumi.Input[str]]
        """
        The force set of the security certificate.
        """
        private_key: NotRequired[pulumi.Input[str]]
        """
        The content of the private key. If the certificate is not enabled, you do not need to enter the content of the private key. To configure the certificate, enter the content of the private key.
        """
        server_certificate: NotRequired[pulumi.Input[str]]
        """
        The content of the security certificate. If the certificate is not enabled, you do not need to enter the content of the security certificate. Please enter the content of the certificate to configure the certificate.
        """
        server_certificate_status: NotRequired[pulumi.Input[str]]
        """
        Whether the HTTPS certificate is enabled. Value:
        - **on**(default): enabled.
        - **off** : not enabled.
        """
elif False:
    DomainNewCertificateConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainNewCertificateConfigArgs:
    def __init__(__self__, *,
                 cert_id: Optional[pulumi.Input[str]] = None,
                 cert_name: Optional[pulumi.Input[str]] = None,
                 cert_region: Optional[pulumi.Input[str]] = None,
                 cert_type: Optional[pulumi.Input[str]] = None,
                 force_set: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 server_certificate: Optional[pulumi.Input[str]] = None,
                 server_certificate_status: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] cert_id: The ID of the certificate. It takes effect only when CertType = cas.
        :param pulumi.Input[str] cert_name: Certificate name, only flyer names are supported.
        :param pulumi.Input[str] cert_region: The certificate region, which takes effect only when CertType = cas, supports cn-hangzhou (domestic) and ap-southeast-1 (International), and is cn-hangzhou by default.
        :param pulumi.Input[str] cert_type: Certificate type. Value:
               - **upload**: upload certificate.
               - **cas**: Cloud Shield certificate.
               - **free**: free certificate.
               > If the certificate type is **cas**, **PrivateKey** does not need to pass parameters.
        :param pulumi.Input[str] force_set: The force set of the security certificate.
        :param pulumi.Input[str] private_key: The content of the private key. If the certificate is not enabled, you do not need to enter the content of the private key. To configure the certificate, enter the content of the private key.
        :param pulumi.Input[str] server_certificate: The content of the security certificate. If the certificate is not enabled, you do not need to enter the content of the security certificate. Please enter the content of the certificate to configure the certificate.
        :param pulumi.Input[str] server_certificate_status: Whether the HTTPS certificate is enabled. Value:
               - **on**(default): enabled.
               - **off** : not enabled.
        """
        if cert_id is not None:
            pulumi.set(__self__, "cert_id", cert_id)
        if cert_name is not None:
            pulumi.set(__self__, "cert_name", cert_name)
        if cert_region is not None:
            pulumi.set(__self__, "cert_region", cert_region)
        if cert_type is not None:
            pulumi.set(__self__, "cert_type", cert_type)
        if force_set is not None:
            pulumi.set(__self__, "force_set", force_set)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if server_certificate is not None:
            pulumi.set(__self__, "server_certificate", server_certificate)
        if server_certificate_status is not None:
            pulumi.set(__self__, "server_certificate_status", server_certificate_status)

    @property
    @pulumi.getter(name="certId")
    def cert_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the certificate. It takes effect only when CertType = cas.
        """
        return pulumi.get(self, "cert_id")

    @cert_id.setter
    def cert_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cert_id", value)

    @property
    @pulumi.getter(name="certName")
    def cert_name(self) -> Optional[pulumi.Input[str]]:
        """
        Certificate name, only flyer names are supported.
        """
        return pulumi.get(self, "cert_name")

    @cert_name.setter
    def cert_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cert_name", value)

    @property
    @pulumi.getter(name="certRegion")
    def cert_region(self) -> Optional[pulumi.Input[str]]:
        """
        The certificate region, which takes effect only when CertType = cas, supports cn-hangzhou (domestic) and ap-southeast-1 (International), and is cn-hangzhou by default.
        """
        return pulumi.get(self, "cert_region")

    @cert_region.setter
    def cert_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cert_region", value)

    @property
    @pulumi.getter(name="certType")
    def cert_type(self) -> Optional[pulumi.Input[str]]:
        """
        Certificate type. Value:
        - **upload**: upload certificate.
        - **cas**: Cloud Shield certificate.
        - **free**: free certificate.
        > If the certificate type is **cas**, **PrivateKey** does not need to pass parameters.
        """
        return pulumi.get(self, "cert_type")

    @cert_type.setter
    def cert_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cert_type", value)

    @property
    @pulumi.getter(name="forceSet")
    def force_set(self) -> Optional[pulumi.Input[str]]:
        """
        The force set of the security certificate.
        """
        return pulumi.get(self, "force_set")

    @force_set.setter
    def force_set(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "force_set", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[str]]:
        """
        The content of the private key. If the certificate is not enabled, you do not need to enter the content of the private key. To configure the certificate, enter the content of the private key.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="serverCertificate")
    def server_certificate(self) -> Optional[pulumi.Input[str]]:
        """
        The content of the security certificate. If the certificate is not enabled, you do not need to enter the content of the security certificate. Please enter the content of the certificate to configure the certificate.
        """
        return pulumi.get(self, "server_certificate")

    @server_certificate.setter
    def server_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server_certificate", value)

    @property
    @pulumi.getter(name="serverCertificateStatus")
    def server_certificate_status(self) -> Optional[pulumi.Input[str]]:
        """
        Whether the HTTPS certificate is enabled. Value:
        - **on**(default): enabled.
        - **off** : not enabled.
        """
        return pulumi.get(self, "server_certificate_status")

    @server_certificate_status.setter
    def server_certificate_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server_certificate_status", value)


if not MYPY:
    class DomainNewSourceArgsDict(TypedDict):
        content: NotRequired[pulumi.Input[str]]
        """
        The address of source. Valid values can be ip or doaminName. Each item's `content` can not be repeated.
        """
        port: NotRequired[pulumi.Input[int]]
        """
        The port of source. Valid values are `443` and `80`. Default value is `80`.
        """
        priority: NotRequired[pulumi.Input[int]]
        """
        Priority of the source. Valid values are `0` and `100`. Default value is `20`.
        """
        type: NotRequired[pulumi.Input[str]]
        """
        The type of the source. Valid values are `ipaddr`, `domain` and `oss`.
        """
        weight: NotRequired[pulumi.Input[int]]
        """
        Weight of the source. Valid values are from `0` to `100`. Default value is `10`, but if type is `ipaddr`, the value can only be `10`. .
        """
elif False:
    DomainNewSourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainNewSourceArgs:
    def __init__(__self__, *,
                 content: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] content: The address of source. Valid values can be ip or doaminName. Each item's `content` can not be repeated.
        :param pulumi.Input[int] port: The port of source. Valid values are `443` and `80`. Default value is `80`.
        :param pulumi.Input[int] priority: Priority of the source. Valid values are `0` and `100`. Default value is `20`.
        :param pulumi.Input[str] type: The type of the source. Valid values are `ipaddr`, `domain` and `oss`.
        :param pulumi.Input[int] weight: Weight of the source. Valid values are from `0` to `100`. Default value is `10`, but if type is `ipaddr`, the value can only be `10`. .
        """
        if content is not None:
            pulumi.set(__self__, "content", content)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[str]]:
        """
        The address of source. Valid values can be ip or doaminName. Each item's `content` can not be repeated.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        The port of source. Valid values are `443` and `80`. Default value is `80`.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        Priority of the source. Valid values are `0` and `100`. Default value is `20`.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the source. Valid values are `ipaddr`, `domain` and `oss`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[int]]:
        """
        Weight of the source. Valid values are from `0` to `100`. Default value is `10`, but if type is `ipaddr`, the value can only be `10`. .
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "weight", value)


if not MYPY:
    class DomainPage404ConfigArgsDict(TypedDict):
        custom_page_url: NotRequired[pulumi.Input[str]]
        error_code: NotRequired[pulumi.Input[str]]
        page_type: NotRequired[pulumi.Input[str]]
elif False:
    DomainPage404ConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainPage404ConfigArgs:
    def __init__(__self__, *,
                 custom_page_url: Optional[pulumi.Input[str]] = None,
                 error_code: Optional[pulumi.Input[str]] = None,
                 page_type: Optional[pulumi.Input[str]] = None):
        if custom_page_url is not None:
            pulumi.set(__self__, "custom_page_url", custom_page_url)
        if error_code is not None:
            pulumi.set(__self__, "error_code", error_code)
        if page_type is not None:
            pulumi.set(__self__, "page_type", page_type)

    @property
    @pulumi.getter(name="customPageUrl")
    def custom_page_url(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "custom_page_url")

    @custom_page_url.setter
    def custom_page_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "custom_page_url", value)

    @property
    @pulumi.getter(name="errorCode")
    def error_code(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "error_code")

    @error_code.setter
    def error_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "error_code", value)

    @property
    @pulumi.getter(name="pageType")
    def page_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "page_type")

    @page_type.setter
    def page_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "page_type", value)


if not MYPY:
    class DomainParameterFilterConfigArgsDict(TypedDict):
        enable: NotRequired[pulumi.Input[str]]
        hash_key_args: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
elif False:
    DomainParameterFilterConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainParameterFilterConfigArgs:
    def __init__(__self__, *,
                 enable: Optional[pulumi.Input[str]] = None,
                 hash_key_args: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        if enable is not None:
            pulumi.set(__self__, "enable", enable)
        if hash_key_args is not None:
            pulumi.set(__self__, "hash_key_args", hash_key_args)

    @property
    @pulumi.getter
    def enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "enable")

    @enable.setter
    def enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enable", value)

    @property
    @pulumi.getter(name="hashKeyArgs")
    def hash_key_args(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hash_key_args")

    @hash_key_args.setter
    def hash_key_args(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hash_key_args", value)


if not MYPY:
    class DomainReferConfigArgsDict(TypedDict):
        refer_lists: pulumi.Input[Sequence[pulumi.Input[str]]]
        allow_empty: NotRequired[pulumi.Input[str]]
        refer_type: NotRequired[pulumi.Input[str]]
elif False:
    DomainReferConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainReferConfigArgs:
    def __init__(__self__, *,
                 refer_lists: pulumi.Input[Sequence[pulumi.Input[str]]],
                 allow_empty: Optional[pulumi.Input[str]] = None,
                 refer_type: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "refer_lists", refer_lists)
        if allow_empty is not None:
            pulumi.set(__self__, "allow_empty", allow_empty)
        if refer_type is not None:
            pulumi.set(__self__, "refer_type", refer_type)

    @property
    @pulumi.getter(name="referLists")
    def refer_lists(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        return pulumi.get(self, "refer_lists")

    @refer_lists.setter
    def refer_lists(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "refer_lists", value)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "allow_empty")

    @allow_empty.setter
    def allow_empty(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "allow_empty", value)

    @property
    @pulumi.getter(name="referType")
    def refer_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "refer_type")

    @refer_type.setter
    def refer_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "refer_type", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from ._inputs import *

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[str]] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 assume_role: Optional[pulumi.Input['ProviderAssumeRoleArgs']] = None,
                 assume_role_with_oidc: Optional[pulumi.Input['ProviderAssumeRoleWithOidcArgs']] = None,
                 client_connect_timeout: Optional[pulumi.Input[int]] = None,
                 client_read_timeout: Optional[pulumi.Input[int]] = None,
                 configuration_source: Optional[pulumi.Input[str]] = None,
                 credentials_uri: Optional[pulumi.Input[str]] = None,
                 ecs_role_name: Optional[pulumi.Input[str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['ProviderEndpointArgs']]]] = None,
                 fc: Optional[pulumi.Input[str]] = None,
                 log_endpoint: Optional[pulumi.Input[str]] = None,
                 max_retry_timeout: Optional[pulumi.Input[int]] = None,
                 mns_endpoint: Optional[pulumi.Input[str]] = None,
                 ots_instance_name: Optional[pulumi.Input[str]] = None,
                 profile: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 secret_key: Optional[pulumi.Input[str]] = None,
                 secure_transport: Optional[pulumi.Input[str]] = None,
                 security_token: Optional[pulumi.Input[str]] = None,
                 security_transport: Optional[pulumi.Input[str]] = None,
                 shared_credentials_file: Optional[pulumi.Input[str]] = None,
                 sign_version: Optional[pulumi.Input['ProviderSignVersionArgs']] = None,
                 skip_region_validation: Optional[pulumi.Input[bool]] = None,
                 source_ip: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] access_key: The access key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
               console.
        :param pulumi.Input[str] account_id: The account ID for some service API operations. You can retrieve this from the 'Security Settings' section of the
               Alibaba Cloud console.
        :param pulumi.Input[int] client_connect_timeout: The maximum timeout of the client connection server.
        :param pulumi.Input[int] client_read_timeout: The maximum timeout of the client read request.
        :param pulumi.Input[str] credentials_uri: The URI of sidecar credentials service.
        :param pulumi.Input[str] ecs_role_name: The RAM Role Name attached on a ECS instance for API operations. You can retrieve this from the 'Access Control' section
               of the Alibaba Cloud console.
        :param pulumi.Input[int] max_retry_timeout: The maximum retry timeout of the request.
        :param pulumi.Input[str] profile: The profile for API operations. If not set, the default profile created with `aliyun configure` will be used.
        :param pulumi.Input[str] region: The region where Alibaba Cloud operations will take place. Examples are cn-beijing, cn-hangzhou, eu-central-1, etc.
        :param pulumi.Input[str] secret_key: The secret key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
               console.
        :param pulumi.Input[str] secure_transport: The security transport for the assume role invoking.
        :param pulumi.Input[str] security_token: security token. A security token is only required if you are using Security Token Service.
        :param pulumi.Input[str] shared_credentials_file: The path to the shared credentials file. If not set this defaults to ~/.aliyun/config.json
        :param pulumi.Input[bool] skip_region_validation: Skip static validation of region ID. Used by users of alternative AlibabaCloud-like APIs or users w/ access to regions
               that are not public (yet).
        :param pulumi.Input[str] source_ip: The source ip for the assume role invoking.
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if assume_role is not None:
            pulumi.set(__self__, "assume_role", assume_role)
        if assume_role_with_oidc is not None:
            pulumi.set(__self__, "assume_role_with_oidc", assume_role_with_oidc)
        if client_connect_timeout is not None:
            pulumi.set(__self__, "client_connect_timeout", client_connect_timeout)
        if client_read_timeout is not None:
            pulumi.set(__self__, "client_read_timeout", client_read_timeout)
        if configuration_source is not None:
            pulumi.set(__self__, "configuration_source", configuration_source)
        if credentials_uri is not None:
            pulumi.set(__self__, "credentials_uri", credentials_uri)
        if ecs_role_name is None:
            ecs_role_name = _utilities.get_env('ALICLOUD_ECS_ROLE_NAME')
        if ecs_role_name is not None:
            pulumi.set(__self__, "ecs_role_name", ecs_role_name)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if fc is not None:
            warnings.warn("""Field 'fc' has been deprecated from provider version 1.28.0. New field 'fc' which in nested endpoints instead.""", DeprecationWarning)
            pulumi.log.warn("""fc is deprecated: Field 'fc' has been deprecated from provider version 1.28.0. New field 'fc' which in nested endpoints instead.""")
        if fc is not None:
            pulumi.set(__self__, "fc", fc)
        if log_endpoint is not None:
            warnings.warn("""Field 'log_endpoint' has been deprecated from provider version 1.28.0. New field 'log' which in nested endpoints instead.""", DeprecationWarning)
            pulumi.log.warn("""log_endpoint is deprecated: Field 'log_endpoint' has been deprecated from provider version 1.28.0. New field 'log' which in nested endpoints instead.""")
        if log_endpoint is not None:
            pulumi.set(__self__, "log_endpoint", log_endpoint)
        if max_retry_timeout is not None:
            pulumi.set(__self__, "max_retry_timeout", max_retry_timeout)
        if mns_endpoint is not None:
            warnings.warn("""Field 'mns_endpoint' has been deprecated from provider version 1.28.0. New field 'mns' which in nested endpoints instead.""", DeprecationWarning)
            pulumi.log.warn("""mns_endpoint is deprecated: Field 'mns_endpoint' has been deprecated from provider version 1.28.0. New field 'mns' which in nested endpoints instead.""")
        if mns_endpoint is not None:
            pulumi.set(__self__, "mns_endpoint", mns_endpoint)
        if ots_instance_name is not None:
            warnings.warn("""Field 'ots_instance_name' has been deprecated from provider version 1.10.0. New field 'instance_name' of resource 'alicloud_ots_table' instead.""", DeprecationWarning)
            pulumi.log.warn("""ots_instance_name is deprecated: Field 'ots_instance_name' has been deprecated from provider version 1.10.0. New field 'instance_name' of resource 'alicloud_ots_table' instead.""")
        if ots_instance_name is not None:
            pulumi.set(__self__, "ots_instance_name", ots_instance_name)
        if profile is None:
            profile = _utilities.get_env('ALICLOUD_PROFILE')
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if region is None:
            region = _utilities.get_env('ALICLOUD_REGION')
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if secure_transport is not None:
            pulumi.set(__self__, "secure_transport", secure_transport)
        if security_token is not None:
            pulumi.set(__self__, "security_token", security_token)
        if security_transport is not None:
            pulumi.set(__self__, "security_transport", security_transport)
        if shared_credentials_file is not None:
            pulumi.set(__self__, "shared_credentials_file", shared_credentials_file)
        if sign_version is not None:
            pulumi.set(__self__, "sign_version", sign_version)
        if skip_region_validation is not None:
            pulumi.set(__self__, "skip_region_validation", skip_region_validation)
        if source_ip is not None:
            pulumi.set(__self__, "source_ip", source_ip)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[str]]:
        """
        The access key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
        console.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_key", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The account ID for some service API operations. You can retrieve this from the 'Security Settings' section of the
        Alibaba Cloud console.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="assumeRole")
    def assume_role(self) -> Optional[pulumi.Input['ProviderAssumeRoleArgs']]:
        return pulumi.get(self, "assume_role")

    @assume_role.setter
    def assume_role(self, value: Optional[pulumi.Input['ProviderAssumeRoleArgs']]):
        pulumi.set(self, "assume_role", value)

    @property
    @pulumi.getter(name="assumeRoleWithOidc")
    def assume_role_with_oidc(self) -> Optional[pulumi.Input['ProviderAssumeRoleWithOidcArgs']]:
        return pulumi.get(self, "assume_role_with_oidc")

    @assume_role_with_oidc.setter
    def assume_role_with_oidc(self, value: Optional[pulumi.Input['ProviderAssumeRoleWithOidcArgs']]):
        pulumi.set(self, "assume_role_with_oidc", value)

    @property
    @pulumi.getter(name="clientConnectTimeout")
    def client_connect_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum timeout of the client connection server.
        """
        return pulumi.get(self, "client_connect_timeout")

    @client_connect_timeout.setter
    def client_connect_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "client_connect_timeout", value)

    @property
    @pulumi.getter(name="clientReadTimeout")
    def client_read_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum timeout of the client read request.
        """
        return pulumi.get(self, "client_read_timeout")

    @client_read_timeout.setter
    def client_read_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "client_read_timeout", value)

    @property
    @pulumi.getter(name="configurationSource")
    def configuration_source(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "configuration_source")

    @configuration_source.setter
    def configuration_source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "configuration_source", value)

    @property
    @pulumi.getter(name="credentialsUri")
    def credentials_uri(self) -> Optional[pulumi.Input[str]]:
        """
        The URI of sidecar credentials service.
        """
        return pulumi.get(self, "credentials_uri")

    @credentials_uri.setter
    def credentials_uri(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "credentials_uri", value)

    @property
    @pulumi.getter(name="ecsRoleName")
    def ecs_role_name(self) -> Optional[pulumi.Input[str]]:
        """
        The RAM Role Name attached on a ECS instance for API operations. You can retrieve this from the 'Access Control' section
        of the Alibaba Cloud console.
        """
        return pulumi.get(self, "ecs_role_name")

    @ecs_role_name.setter
    def ecs_role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ecs_role_name", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProviderEndpointArgs']]]]:
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProviderEndpointArgs']]]]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'fc' has been deprecated from provider version 1.28.0. New field 'fc' which in nested endpoints instead.""")
    def fc(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "fc")

    @fc.setter
    def fc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fc", value)

    @property
    @pulumi.getter(name="logEndpoint")
    @_utilities.deprecated("""Field 'log_endpoint' has been deprecated from provider version 1.28.0. New field 'log' which in nested endpoints instead.""")
    def log_endpoint(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "log_endpoint")

    @log_endpoint.setter
    def log_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_endpoint", value)

    @property
    @pulumi.getter(name="maxRetryTimeout")
    def max_retry_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum retry timeout of the request.
        """
        return pulumi.get(self, "max_retry_timeout")

    @max_retry_timeout.setter
    def max_retry_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_retry_timeout", value)

    @property
    @pulumi.getter(name="mnsEndpoint")
    @_utilities.deprecated("""Field 'mns_endpoint' has been deprecated from provider version 1.28.0. New field 'mns' which in nested endpoints instead.""")
    def mns_endpoint(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "mns_endpoint")

    @mns_endpoint.setter
    def mns_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mns_endpoint", value)

    @property
    @pulumi.getter(name="otsInstanceName")
    @_utilities.deprecated("""Field 'ots_instance_name' has been deprecated from provider version 1.10.0. New field 'instance_name' of resource 'alicloud_ots_table' instead.""")
    def ots_instance_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ots_instance_name")

    @ots_instance_name.setter
    def ots_instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ots_instance_name", value)

    @property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[str]]:
        """
        The profile for API operations. If not set, the default profile created with `aliyun configure` will be used.
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "profile", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region where Alibaba Cloud operations will take place. Examples are cn-beijing, cn-hangzhou, eu-central-1, etc.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[str]]:
        """
        The secret key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
        console.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_key", value)

    @property
    @pulumi.getter(name="secureTransport")
    def secure_transport(self) -> Optional[pulumi.Input[str]]:
        """
        The security transport for the assume role invoking.
        """
        return pulumi.get(self, "secure_transport")

    @secure_transport.setter
    def secure_transport(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secure_transport", value)

    @property
    @pulumi.getter(name="securityToken")
    def security_token(self) -> Optional[pulumi.Input[str]]:
        """
        security token. A security token is only required if you are using Security Token Service.
        """
        return pulumi.get(self, "security_token")

    @security_token.setter
    def security_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_token", value)

    @property
    @pulumi.getter(name="securityTransport")
    def security_transport(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "security_transport")

    @security_transport.setter
    def security_transport(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_transport", value)

    @property
    @pulumi.getter(name="sharedCredentialsFile")
    def shared_credentials_file(self) -> Optional[pulumi.Input[str]]:
        """
        The path to the shared credentials file. If not set this defaults to ~/.aliyun/config.json
        """
        return pulumi.get(self, "shared_credentials_file")

    @shared_credentials_file.setter
    def shared_credentials_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "shared_credentials_file", value)

    @property
    @pulumi.getter(name="signVersion")
    def sign_version(self) -> Optional[pulumi.Input['ProviderSignVersionArgs']]:
        return pulumi.get(self, "sign_version")

    @sign_version.setter
    def sign_version(self, value: Optional[pulumi.Input['ProviderSignVersionArgs']]):
        pulumi.set(self, "sign_version", value)

    @property
    @pulumi.getter(name="skipRegionValidation")
    def skip_region_validation(self) -> Optional[pulumi.Input[bool]]:
        """
        Skip static validation of region ID. Used by users of alternative AlibabaCloud-like APIs or users w/ access to regions
        that are not public (yet).
        """
        return pulumi.get(self, "skip_region_validation")

    @skip_region_validation.setter
    def skip_region_validation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_region_validation", value)

    @property
    @pulumi.getter(name="sourceIp")
    def source_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The source ip for the assume role invoking.
        """
        return pulumi.get(self, "source_ip")

    @source_ip.setter
    def source_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_ip", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[str]] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 assume_role: Optional[pulumi.Input[Union['ProviderAssumeRoleArgs', 'ProviderAssumeRoleArgsDict']]] = None,
                 assume_role_with_oidc: Optional[pulumi.Input[Union['ProviderAssumeRoleWithOidcArgs', 'ProviderAssumeRoleWithOidcArgsDict']]] = None,
                 client_connect_timeout: Optional[pulumi.Input[int]] = None,
                 client_read_timeout: Optional[pulumi.Input[int]] = None,
                 configuration_source: Optional[pulumi.Input[str]] = None,
                 credentials_uri: Optional[pulumi.Input[str]] = None,
                 ecs_role_name: Optional[pulumi.Input[str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProviderEndpointArgs', 'ProviderEndpointArgsDict']]]]] = None,
                 fc: Optional[pulumi.Input[str]] = None,
                 log_endpoint: Optional[pulumi.Input[str]] = None,
                 max_retry_timeout: Optional[pulumi.Input[int]] = None,
                 mns_endpoint: Optional[pulumi.Input[str]] = None,
                 ots_instance_name: Optional[pulumi.Input[str]] = None,
                 profile: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 secret_key: Optional[pulumi.Input[str]] = None,
                 secure_transport: Optional[pulumi.Input[str]] = None,
                 security_token: Optional[pulumi.Input[str]] = None,
                 security_transport: Optional[pulumi.Input[str]] = None,
                 shared_credentials_file: Optional[pulumi.Input[str]] = None,
                 sign_version: Optional[pulumi.Input[Union['ProviderSignVersionArgs', 'ProviderSignVersionArgsDict']]] = None,
                 skip_region_validation: Optional[pulumi.Input[bool]] = None,
                 source_ip: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the alicloud package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_key: The access key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
               console.
        :param pulumi.Input[str] account_id: The account ID for some service API operations. You can retrieve this from the 'Security Settings' section of the
               Alibaba Cloud console.
        :param pulumi.Input[int] client_connect_timeout: The maximum timeout of the client connection server.
        :param pulumi.Input[int] client_read_timeout: The maximum timeout of the client read request.
        :param pulumi.Input[str] credentials_uri: The URI of sidecar credentials service.
        :param pulumi.Input[str] ecs_role_name: The RAM Role Name attached on a ECS instance for API operations. You can retrieve this from the 'Access Control' section
               of the Alibaba Cloud console.
        :param pulumi.Input[int] max_retry_timeout: The maximum retry timeout of the request.
        :param pulumi.Input[str] profile: The profile for API operations. If not set, the default profile created with `aliyun configure` will be used.
        :param pulumi.Input[str] region: The region where Alibaba Cloud operations will take place. Examples are cn-beijing, cn-hangzhou, eu-central-1, etc.
        :param pulumi.Input[str] secret_key: The secret key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
               console.
        :param pulumi.Input[str] secure_transport: The security transport for the assume role invoking.
        :param pulumi.Input[str] security_token: security token. A security token is only required if you are using Security Token Service.
        :param pulumi.Input[str] shared_credentials_file: The path to the shared credentials file. If not set this defaults to ~/.aliyun/config.json
        :param pulumi.Input[bool] skip_region_validation: Skip static validation of region ID. Used by users of alternative AlibabaCloud-like APIs or users w/ access to regions
               that are not public (yet).
        :param pulumi.Input[str] source_ip: The source ip for the assume role invoking.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the alicloud package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[str]] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 assume_role: Optional[pulumi.Input[Union['ProviderAssumeRoleArgs', 'ProviderAssumeRoleArgsDict']]] = None,
                 assume_role_with_oidc: Optional[pulumi.Input[Union['ProviderAssumeRoleWithOidcArgs', 'ProviderAssumeRoleWithOidcArgsDict']]] = None,
                 client_connect_timeout: Optional[pulumi.Input[int]] = None,
                 client_read_timeout: Optional[pulumi.Input[int]] = None,
                 configuration_source: Optional[pulumi.Input[str]] = None,
                 credentials_uri: Optional[pulumi.Input[str]] = None,
                 ecs_role_name: Optional[pulumi.Input[str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProviderEndpointArgs', 'ProviderEndpointArgsDict']]]]] = None,
                 fc: Optional[pulumi.Input[str]] = None,
                 log_endpoint: Optional[pulumi.Input[str]] = None,
                 max_retry_timeout: Optional[pulumi.Input[int]] = None,
                 mns_endpoint: Optional[pulumi.Input[str]] = None,
                 ots_instance_name: Optional[pulumi.Input[str]] = None,
                 profile: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 secret_key: Optional[pulumi.Input[str]] = None,
                 secure_transport: Optional[pulumi.Input[str]] = None,
                 security_token: Optional[pulumi.Input[str]] = None,
                 security_transport: Optional[pulumi.Input[str]] = None,
                 shared_credentials_file: Optional[pulumi.Input[str]] = None,
                 sign_version: Optional[pulumi.Input[Union['ProviderSignVersionArgs', 'ProviderSignVersionArgsDict']]] = None,
                 skip_region_validation: Optional[pulumi.Input[bool]] = None,
                 source_ip: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["access_key"] = access_key
            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["assume_role"] = pulumi.Output.from_input(assume_role).apply(pulumi.runtime.to_json) if assume_role is not None else None
            __props__.__dict__["assume_role_with_oidc"] = pulumi.Output.from_input(assume_role_with_oidc).apply(pulumi.runtime.to_json) if assume_role_with_oidc is not None else None
            __props__.__dict__["client_connect_timeout"] = pulumi.Output.from_input(client_connect_timeout).apply(pulumi.runtime.to_json) if client_connect_timeout is not None else None
            __props__.__dict__["client_read_timeout"] = pulumi.Output.from_input(client_read_timeout).apply(pulumi.runtime.to_json) if client_read_timeout is not None else None
            __props__.__dict__["configuration_source"] = configuration_source
            __props__.__dict__["credentials_uri"] = credentials_uri
            if ecs_role_name is None:
                ecs_role_name = _utilities.get_env('ALICLOUD_ECS_ROLE_NAME')
            __props__.__dict__["ecs_role_name"] = ecs_role_name
            __props__.__dict__["endpoints"] = pulumi.Output.from_input(endpoints).apply(pulumi.runtime.to_json) if endpoints is not None else None
            __props__.__dict__["fc"] = fc
            __props__.__dict__["log_endpoint"] = log_endpoint
            __props__.__dict__["max_retry_timeout"] = pulumi.Output.from_input(max_retry_timeout).apply(pulumi.runtime.to_json) if max_retry_timeout is not None else None
            __props__.__dict__["mns_endpoint"] = mns_endpoint
            __props__.__dict__["ots_instance_name"] = ots_instance_name
            if profile is None:
                profile = _utilities.get_env('ALICLOUD_PROFILE')
            __props__.__dict__["profile"] = profile
            __props__.__dict__["protocol"] = protocol
            if region is None:
                region = _utilities.get_env('ALICLOUD_REGION')
            __props__.__dict__["region"] = region
            __props__.__dict__["secret_key"] = secret_key
            __props__.__dict__["secure_transport"] = secure_transport
            __props__.__dict__["security_token"] = security_token
            __props__.__dict__["security_transport"] = security_transport
            __props__.__dict__["shared_credentials_file"] = shared_credentials_file
            __props__.__dict__["sign_version"] = pulumi.Output.from_input(sign_version).apply(pulumi.runtime.to_json) if sign_version is not None else None
            __props__.__dict__["skip_region_validation"] = pulumi.Output.from_input(skip_region_validation).apply(pulumi.runtime.to_json) if skip_region_validation is not None else None
            __props__.__dict__["source_ip"] = source_ip
        super(Provider, __self__).__init__(
            'alicloud',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[Optional[str]]:
        """
        The access key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
        console.
        """
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[Optional[str]]:
        """
        The account ID for some service API operations. You can retrieve this from the 'Security Settings' section of the
        Alibaba Cloud console.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="configurationSource")
    def configuration_source(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "configuration_source")

    @property
    @pulumi.getter(name="credentialsUri")
    def credentials_uri(self) -> pulumi.Output[Optional[str]]:
        """
        The URI of sidecar credentials service.
        """
        return pulumi.get(self, "credentials_uri")

    @property
    @pulumi.getter(name="ecsRoleName")
    def ecs_role_name(self) -> pulumi.Output[Optional[str]]:
        """
        The RAM Role Name attached on a ECS instance for API operations. You can retrieve this from the 'Access Control' section
        of the Alibaba Cloud console.
        """
        return pulumi.get(self, "ecs_role_name")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'fc' has been deprecated from provider version 1.28.0. New field 'fc' which in nested endpoints instead.""")
    def fc(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "fc")

    @property
    @pulumi.getter(name="logEndpoint")
    @_utilities.deprecated("""Field 'log_endpoint' has been deprecated from provider version 1.28.0. New field 'log' which in nested endpoints instead.""")
    def log_endpoint(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "log_endpoint")

    @property
    @pulumi.getter(name="mnsEndpoint")
    @_utilities.deprecated("""Field 'mns_endpoint' has been deprecated from provider version 1.28.0. New field 'mns' which in nested endpoints instead.""")
    def mns_endpoint(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "mns_endpoint")

    @property
    @pulumi.getter(name="otsInstanceName")
    @_utilities.deprecated("""Field 'ots_instance_name' has been deprecated from provider version 1.10.0. New field 'instance_name' of resource 'alicloud_ots_table' instead.""")
    def ots_instance_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "ots_instance_name")

    @property
    @pulumi.getter
    def profile(self) -> pulumi.Output[Optional[str]]:
        """
        The profile for API operations. If not set, the default profile created with `aliyun configure` will be used.
        """
        return pulumi.get(self, "profile")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[str]]:
        """
        The region where Alibaba Cloud operations will take place. Examples are cn-beijing, cn-hangzhou, eu-central-1, etc.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[Optional[str]]:
        """
        The secret key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
        console.
        """
        return pulumi.get(self, "secret_key")

    @property
    @pulumi.getter(name="secureTransport")
    def secure_transport(self) -> pulumi.Output[Optional[str]]:
        """
        The security transport for the assume role invoking.
        """
        return pulumi.get(self, "secure_transport")

    @property
    @pulumi.getter(name="securityToken")
    def security_token(self) -> pulumi.Output[Optional[str]]:
        """
        security token. A security token is only required if you are using Security Token Service.
        """
        return pulumi.get(self, "security_token")

    @property
    @pulumi.getter(name="securityTransport")
    def security_transport(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "security_transport")

    @property
    @pulumi.getter(name="sharedCredentialsFile")
    def shared_credentials_file(self) -> pulumi.Output[Optional[str]]:
        """
        The path to the shared credentials file. If not set this defaults to ~/.aliyun/config.json
        """
        return pulumi.get(self, "shared_credentials_file")

    @property
    @pulumi.getter(name="sourceIp")
    def source_ip(self) -> pulumi.Output[Optional[str]]:
        """
        The source ip for the assume role invoking.
        """
        return pulumi.get(self, "source_ip")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__):
        """
        The set of arguments for constructing a Instance resource.
        """
        pass


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] instance_id: The first ID of the resource
        :param pulumi.Input[str] status: The status of the resource
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 __props__=None):
        """
        Provides a Wafv3 Instance resource.

        For information about Wafv3 Instance and how to use it, see [What is Instance](https://www.alibabacloud.com/help/en/web-application-firewall/latest/what-is-waf).

        > **NOTE:** Available in v1.200.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.wafv3.Instance("default")
        ```

        ## Import

        Wafv3 Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:wafv3/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[InstanceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Wafv3 Instance resource.

        For information about Wafv3 Instance and how to use it, see [What is Instance](https://www.alibabacloud.com/help/en/web-application-firewall/latest/what-is-waf).

        > **NOTE:** Available in v1.200.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.wafv3.Instance("default")
        ```

        ## Import

        Wafv3 Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:wafv3/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["create_time"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["status"] = None
        super(Instance, __self__).__init__(
            'alicloud:wafv3/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] instance_id: The first ID of the resource
        :param pulumi.Input[str] status: The status of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["status"] = status
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccountArgs', 'Account']

@pulumi.input_type
class AccountArgs:
    def __init__(__self__, *,
                 baseline_id: pulumi.Input[str],
                 account_id: Optional[pulumi.Input[int]] = None,
                 account_name_prefix: Optional[pulumi.Input[str]] = None,
                 account_tags: Optional[pulumi.Input[Sequence[pulumi.Input['AccountAccountTagArgs']]]] = None,
                 default_domain_name: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 folder_id: Optional[pulumi.Input[str]] = None,
                 payer_account_id: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Account resource.
        :param pulumi.Input[str] baseline_id: The baseline ID.
               
               If it is left blank, the system default baseline is used by default.
        :param pulumi.Input[int] account_id: The ID of the enrolled account.
               - If you are creating a new resource account, this parameter is not required.
               - If you are enrolling a existing account to account factory, this parameter is required.
        :param pulumi.Input[str] account_name_prefix: Account name prefix.
               - This parameter is required if you are creating a new resource account.
               - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[Sequence[pulumi.Input['AccountAccountTagArgs']]] account_tags: The tags of the account See `account_tags` below.
        :param pulumi.Input[str] default_domain_name: The domain name is used to qualify the login name of RAM users and RAM roles.
        :param pulumi.Input[str] display_name: The account display name.
               - This parameter is required if you are creating a new resource account.
               - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[str] folder_id: The ID of the parent resource folder.
               
               If you want to create a new resource account and leave this parameter blank, the account is created in the Root folder by default.
               
               If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[int] payer_account_id: The ID of the billing account. If you leave this parameter empty, the current account is used as the billing account.
        """
        pulumi.set(__self__, "baseline_id", baseline_id)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if account_name_prefix is not None:
            pulumi.set(__self__, "account_name_prefix", account_name_prefix)
        if account_tags is not None:
            pulumi.set(__self__, "account_tags", account_tags)
        if default_domain_name is not None:
            pulumi.set(__self__, "default_domain_name", default_domain_name)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if folder_id is not None:
            pulumi.set(__self__, "folder_id", folder_id)
        if payer_account_id is not None:
            pulumi.set(__self__, "payer_account_id", payer_account_id)

    @property
    @pulumi.getter(name="baselineId")
    def baseline_id(self) -> pulumi.Input[str]:
        """
        The baseline ID.

        If it is left blank, the system default baseline is used by default.
        """
        return pulumi.get(self, "baseline_id")

    @baseline_id.setter
    def baseline_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "baseline_id", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the enrolled account.
        - If you are creating a new resource account, this parameter is not required.
        - If you are enrolling a existing account to account factory, this parameter is required.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="accountNamePrefix")
    def account_name_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Account name prefix.
        - This parameter is required if you are creating a new resource account.
        - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "account_name_prefix")

    @account_name_prefix.setter
    def account_name_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_name_prefix", value)

    @property
    @pulumi.getter(name="accountTags")
    def account_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccountAccountTagArgs']]]]:
        """
        The tags of the account See `account_tags` below.
        """
        return pulumi.get(self, "account_tags")

    @account_tags.setter
    def account_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccountAccountTagArgs']]]]):
        pulumi.set(self, "account_tags", value)

    @property
    @pulumi.getter(name="defaultDomainName")
    def default_domain_name(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name is used to qualify the login name of RAM users and RAM roles.
        """
        return pulumi.get(self, "default_domain_name")

    @default_domain_name.setter
    def default_domain_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_domain_name", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The account display name.
        - This parameter is required if you are creating a new resource account.
        - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the parent resource folder.

        If you want to create a new resource account and leave this parameter blank, the account is created in the Root folder by default.

        If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "folder_id")

    @folder_id.setter
    def folder_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_id", value)

    @property
    @pulumi.getter(name="payerAccountId")
    def payer_account_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the billing account. If you leave this parameter empty, the current account is used as the billing account.
        """
        return pulumi.get(self, "payer_account_id")

    @payer_account_id.setter
    def payer_account_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "payer_account_id", value)


@pulumi.input_type
class _AccountState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[int]] = None,
                 account_name_prefix: Optional[pulumi.Input[str]] = None,
                 account_tags: Optional[pulumi.Input[Sequence[pulumi.Input['AccountAccountTagArgs']]]] = None,
                 baseline_id: Optional[pulumi.Input[str]] = None,
                 default_domain_name: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 folder_id: Optional[pulumi.Input[str]] = None,
                 payer_account_id: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Account resources.
        :param pulumi.Input[int] account_id: The ID of the enrolled account.
               - If you are creating a new resource account, this parameter is not required.
               - If you are enrolling a existing account to account factory, this parameter is required.
        :param pulumi.Input[str] account_name_prefix: Account name prefix.
               - This parameter is required if you are creating a new resource account.
               - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[Sequence[pulumi.Input['AccountAccountTagArgs']]] account_tags: The tags of the account See `account_tags` below.
        :param pulumi.Input[str] baseline_id: The baseline ID.
               
               If it is left blank, the system default baseline is used by default.
        :param pulumi.Input[str] default_domain_name: The domain name is used to qualify the login name of RAM users and RAM roles.
        :param pulumi.Input[str] display_name: The account display name.
               - This parameter is required if you are creating a new resource account.
               - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[str] folder_id: The ID of the parent resource folder.
               
               If you want to create a new resource account and leave this parameter blank, the account is created in the Root folder by default.
               
               If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[int] payer_account_id: The ID of the billing account. If you leave this parameter empty, the current account is used as the billing account.
        :param pulumi.Input[str] status: Account registration status. Value:
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if account_name_prefix is not None:
            pulumi.set(__self__, "account_name_prefix", account_name_prefix)
        if account_tags is not None:
            pulumi.set(__self__, "account_tags", account_tags)
        if baseline_id is not None:
            pulumi.set(__self__, "baseline_id", baseline_id)
        if default_domain_name is not None:
            pulumi.set(__self__, "default_domain_name", default_domain_name)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if folder_id is not None:
            pulumi.set(__self__, "folder_id", folder_id)
        if payer_account_id is not None:
            pulumi.set(__self__, "payer_account_id", payer_account_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the enrolled account.
        - If you are creating a new resource account, this parameter is not required.
        - If you are enrolling a existing account to account factory, this parameter is required.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="accountNamePrefix")
    def account_name_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Account name prefix.
        - This parameter is required if you are creating a new resource account.
        - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "account_name_prefix")

    @account_name_prefix.setter
    def account_name_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_name_prefix", value)

    @property
    @pulumi.getter(name="accountTags")
    def account_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccountAccountTagArgs']]]]:
        """
        The tags of the account See `account_tags` below.
        """
        return pulumi.get(self, "account_tags")

    @account_tags.setter
    def account_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccountAccountTagArgs']]]]):
        pulumi.set(self, "account_tags", value)

    @property
    @pulumi.getter(name="baselineId")
    def baseline_id(self) -> Optional[pulumi.Input[str]]:
        """
        The baseline ID.

        If it is left blank, the system default baseline is used by default.
        """
        return pulumi.get(self, "baseline_id")

    @baseline_id.setter
    def baseline_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "baseline_id", value)

    @property
    @pulumi.getter(name="defaultDomainName")
    def default_domain_name(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name is used to qualify the login name of RAM users and RAM roles.
        """
        return pulumi.get(self, "default_domain_name")

    @default_domain_name.setter
    def default_domain_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_domain_name", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The account display name.
        - This parameter is required if you are creating a new resource account.
        - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the parent resource folder.

        If you want to create a new resource account and leave this parameter blank, the account is created in the Root folder by default.

        If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "folder_id")

    @folder_id.setter
    def folder_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_id", value)

    @property
    @pulumi.getter(name="payerAccountId")
    def payer_account_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the billing account. If you leave this parameter empty, the current account is used as the billing account.
        """
        return pulumi.get(self, "payer_account_id")

    @payer_account_id.setter
    def payer_account_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "payer_account_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Account registration status. Value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class Account(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[int]] = None,
                 account_name_prefix: Optional[pulumi.Input[str]] = None,
                 account_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccountAccountTagArgs', 'AccountAccountTagArgsDict']]]]] = None,
                 baseline_id: Optional[pulumi.Input[str]] = None,
                 default_domain_name: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 folder_id: Optional[pulumi.Input[str]] = None,
                 payer_account_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        ## Import

        Governance Account can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:governance/account:Account example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] account_id: The ID of the enrolled account.
               - If you are creating a new resource account, this parameter is not required.
               - If you are enrolling a existing account to account factory, this parameter is required.
        :param pulumi.Input[str] account_name_prefix: Account name prefix.
               - This parameter is required if you are creating a new resource account.
               - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AccountAccountTagArgs', 'AccountAccountTagArgsDict']]]] account_tags: The tags of the account See `account_tags` below.
        :param pulumi.Input[str] baseline_id: The baseline ID.
               
               If it is left blank, the system default baseline is used by default.
        :param pulumi.Input[str] default_domain_name: The domain name is used to qualify the login name of RAM users and RAM roles.
        :param pulumi.Input[str] display_name: The account display name.
               - This parameter is required if you are creating a new resource account.
               - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[str] folder_id: The ID of the parent resource folder.
               
               If you want to create a new resource account and leave this parameter blank, the account is created in the Root folder by default.
               
               If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[int] payer_account_id: The ID of the billing account. If you leave this parameter empty, the current account is used as the billing account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Governance Account can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:governance/account:Account example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[int]] = None,
                 account_name_prefix: Optional[pulumi.Input[str]] = None,
                 account_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccountAccountTagArgs', 'AccountAccountTagArgsDict']]]]] = None,
                 baseline_id: Optional[pulumi.Input[str]] = None,
                 default_domain_name: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 folder_id: Optional[pulumi.Input[str]] = None,
                 payer_account_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountArgs.__new__(AccountArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["account_name_prefix"] = account_name_prefix
            __props__.__dict__["account_tags"] = account_tags
            if baseline_id is None and not opts.urn:
                raise TypeError("Missing required property 'baseline_id'")
            __props__.__dict__["baseline_id"] = baseline_id
            __props__.__dict__["default_domain_name"] = default_domain_name
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["folder_id"] = folder_id
            __props__.__dict__["payer_account_id"] = payer_account_id
            __props__.__dict__["status"] = None
        super(Account, __self__).__init__(
            'alicloud:governance/account:Account',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[int]] = None,
            account_name_prefix: Optional[pulumi.Input[str]] = None,
            account_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccountAccountTagArgs', 'AccountAccountTagArgsDict']]]]] = None,
            baseline_id: Optional[pulumi.Input[str]] = None,
            default_domain_name: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            folder_id: Optional[pulumi.Input[str]] = None,
            payer_account_id: Optional[pulumi.Input[int]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'Account':
        """
        Get an existing Account resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] account_id: The ID of the enrolled account.
               - If you are creating a new resource account, this parameter is not required.
               - If you are enrolling a existing account to account factory, this parameter is required.
        :param pulumi.Input[str] account_name_prefix: Account name prefix.
               - This parameter is required if you are creating a new resource account.
               - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AccountAccountTagArgs', 'AccountAccountTagArgsDict']]]] account_tags: The tags of the account See `account_tags` below.
        :param pulumi.Input[str] baseline_id: The baseline ID.
               
               If it is left blank, the system default baseline is used by default.
        :param pulumi.Input[str] default_domain_name: The domain name is used to qualify the login name of RAM users and RAM roles.
        :param pulumi.Input[str] display_name: The account display name.
               - This parameter is required if you are creating a new resource account.
               - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[str] folder_id: The ID of the parent resource folder.
               
               If you want to create a new resource account and leave this parameter blank, the account is created in the Root folder by default.
               
               If the registration application is applied to an existing account, this parameter does not need to be filled in.
        :param pulumi.Input[int] payer_account_id: The ID of the billing account. If you leave this parameter empty, the current account is used as the billing account.
        :param pulumi.Input[str] status: Account registration status. Value:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountState.__new__(_AccountState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["account_name_prefix"] = account_name_prefix
        __props__.__dict__["account_tags"] = account_tags
        __props__.__dict__["baseline_id"] = baseline_id
        __props__.__dict__["default_domain_name"] = default_domain_name
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["folder_id"] = folder_id
        __props__.__dict__["payer_account_id"] = payer_account_id
        __props__.__dict__["status"] = status
        return Account(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[int]:
        """
        The ID of the enrolled account.
        - If you are creating a new resource account, this parameter is not required.
        - If you are enrolling a existing account to account factory, this parameter is required.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="accountNamePrefix")
    def account_name_prefix(self) -> pulumi.Output[Optional[str]]:
        """
        Account name prefix.
        - This parameter is required if you are creating a new resource account.
        - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "account_name_prefix")

    @property
    @pulumi.getter(name="accountTags")
    def account_tags(self) -> pulumi.Output[Optional[Sequence['outputs.AccountAccountTag']]]:
        """
        The tags of the account See `account_tags` below.
        """
        return pulumi.get(self, "account_tags")

    @property
    @pulumi.getter(name="baselineId")
    def baseline_id(self) -> pulumi.Output[str]:
        """
        The baseline ID.

        If it is left blank, the system default baseline is used by default.
        """
        return pulumi.get(self, "baseline_id")

    @property
    @pulumi.getter(name="defaultDomainName")
    def default_domain_name(self) -> pulumi.Output[Optional[str]]:
        """
        The domain name is used to qualify the login name of RAM users and RAM roles.
        """
        return pulumi.get(self, "default_domain_name")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[str]]:
        """
        The account display name.
        - This parameter is required if you are creating a new resource account.
        - If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the parent resource folder.

        If you want to create a new resource account and leave this parameter blank, the account is created in the Root folder by default.

        If the registration application is applied to an existing account, this parameter does not need to be filled in.
        """
        return pulumi.get(self, "folder_id")

    @property
    @pulumi.getter(name="payerAccountId")
    def payer_account_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the billing account. If you leave this parameter empty, the current account is used as the billing account.
        """
        return pulumi.get(self, "payer_account_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Account registration status. Value:
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerlessKubernetesClustersResult',
    'AwaitableGetServerlessKubernetesClustersResult',
    'get_serverless_kubernetes_clusters',
    'get_serverless_kubernetes_clusters_output',
]

@pulumi.output_type
class GetServerlessKubernetesClustersResult:
    """
    A collection of values returned by getServerlessKubernetesClusters.
    """
    def __init__(__self__, clusters=None, enable_details=None, id=None, ids=None, kube_config_file_prefix=None, name_regex=None, names=None, output_file=None):
        if clusters and not isinstance(clusters, list):
            raise TypeError("Expected argument 'clusters' to be a list")
        pulumi.set(__self__, "clusters", clusters)
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if kube_config_file_prefix and not isinstance(kube_config_file_prefix, str):
            raise TypeError("Expected argument 'kube_config_file_prefix' to be a str")
        pulumi.set(__self__, "kube_config_file_prefix", kube_config_file_prefix)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def clusters(self) -> Sequence['outputs.GetServerlessKubernetesClustersClusterResult']:
        """
        A list of matched Kubernetes clusters. Each element contains the following attributes:
        """
        return pulumi.get(self, "clusters")

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of matched Kubernetes clusters' ids.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="kubeConfigFilePrefix")
    def kube_config_file_prefix(self) -> Optional[str]:
        return pulumi.get(self, "kube_config_file_prefix")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of matched Kubernetes clusters' names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetServerlessKubernetesClustersResult(GetServerlessKubernetesClustersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerlessKubernetesClustersResult(
            clusters=self.clusters,
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            kube_config_file_prefix=self.kube_config_file_prefix,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file)


def get_serverless_kubernetes_clusters(enable_details: Optional[bool] = None,
                                       ids: Optional[Sequence[str]] = None,
                                       kube_config_file_prefix: Optional[str] = None,
                                       name_regex: Optional[str] = None,
                                       output_file: Optional[str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerlessKubernetesClustersResult:
    """
    This data source provides a list Container Service Serverless Kubernetes Clusters on Alibaba Cloud.

    > **NOTE:** Available in 1.58.0+

    > **NOTE:** From version 1.177.0+, We supported batch export of clusters' kube config information by `kube_config_file_prefix`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    # Declare the data source
    k8s_clusters = alicloud.cs.get_serverless_kubernetes_clusters(name_regex="my-first-k8s",
        output_file="my-first-k8s-json",
        kube_config_file_prefix="~/.kube/serverless")
    pulumi.export("output", k8s_clusters.clusters)
    ```


    :param bool enable_details: Boolean, false by default, only `id` and `name` are exported. Set to true if more details are needed, e.g.,  `deletion_protection`, `connections`. See full list in attributes.
    :param Sequence[str] ids: Cluster IDs to filter.
    :param str kube_config_file_prefix: The path prefix of kube config. You could store kube config in a specified directory by specifying this field, like `~/.kube/serverless`, then it will be named with `~/.kube/serverless-clusterID-kubeconfig`. From version 1.187.0+, kube_config will not export kube_config if this field is not set.
    :param str name_regex: A regex string to filter results by cluster name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['kubeConfigFilePrefix'] = kube_config_file_prefix
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cs/getServerlessKubernetesClusters:getServerlessKubernetesClusters', __args__, opts=opts, typ=GetServerlessKubernetesClustersResult).value

    return AwaitableGetServerlessKubernetesClustersResult(
        clusters=pulumi.get(__ret__, 'clusters'),
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        kube_config_file_prefix=pulumi.get(__ret__, 'kube_config_file_prefix'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_serverless_kubernetes_clusters_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                                              ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                              kube_config_file_prefix: Optional[pulumi.Input[Optional[str]]] = None,
                                              name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                              output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetServerlessKubernetesClustersResult]:
    """
    This data source provides a list Container Service Serverless Kubernetes Clusters on Alibaba Cloud.

    > **NOTE:** Available in 1.58.0+

    > **NOTE:** From version 1.177.0+, We supported batch export of clusters' kube config information by `kube_config_file_prefix`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    # Declare the data source
    k8s_clusters = alicloud.cs.get_serverless_kubernetes_clusters(name_regex="my-first-k8s",
        output_file="my-first-k8s-json",
        kube_config_file_prefix="~/.kube/serverless")
    pulumi.export("output", k8s_clusters.clusters)
    ```


    :param bool enable_details: Boolean, false by default, only `id` and `name` are exported. Set to true if more details are needed, e.g.,  `deletion_protection`, `connections`. See full list in attributes.
    :param Sequence[str] ids: Cluster IDs to filter.
    :param str kube_config_file_prefix: The path prefix of kube config. You could store kube config in a specified directory by specifying this field, like `~/.kube/serverless`, then it will be named with `~/.kube/serverless-clusterID-kubeconfig`. From version 1.187.0+, kube_config will not export kube_config if this field is not set.
    :param str name_regex: A regex string to filter results by cluster name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['kubeConfigFilePrefix'] = kube_config_file_prefix
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cs/getServerlessKubernetesClusters:getServerlessKubernetesClusters', __args__, opts=opts, typ=GetServerlessKubernetesClustersResult)
    return __ret__.apply(lambda __response__: GetServerlessKubernetesClustersResult(
        clusters=pulumi.get(__response__, 'clusters'),
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        kube_config_file_prefix=pulumi.get(__response__, 'kube_config_file_prefix'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEndpointGroupsResult',
    'AwaitableGetEndpointGroupsResult',
    'get_endpoint_groups',
    'get_endpoint_groups_output',
]

@pulumi.output_type
class GetEndpointGroupsResult:
    """
    A collection of values returned by getEndpointGroups.
    """
    def __init__(__self__, accelerator_id=None, endpoint_group_type=None, groups=None, id=None, ids=None, listener_id=None, name_regex=None, names=None, output_file=None, status=None):
        if accelerator_id and not isinstance(accelerator_id, str):
            raise TypeError("Expected argument 'accelerator_id' to be a str")
        pulumi.set(__self__, "accelerator_id", accelerator_id)
        if endpoint_group_type and not isinstance(endpoint_group_type, str):
            raise TypeError("Expected argument 'endpoint_group_type' to be a str")
        pulumi.set(__self__, "endpoint_group_type", endpoint_group_type)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if listener_id and not isinstance(listener_id, str):
            raise TypeError("Expected argument 'listener_id' to be a str")
        pulumi.set(__self__, "listener_id", listener_id)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="acceleratorId")
    def accelerator_id(self) -> str:
        return pulumi.get(self, "accelerator_id")

    @property
    @pulumi.getter(name="endpointGroupType")
    def endpoint_group_type(self) -> Optional[str]:
        return pulumi.get(self, "endpoint_group_type")

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetEndpointGroupsGroupResult']:
        """
        A list of Ga Endpoint Groups. Each element contains the following attributes:
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> Optional[str]:
        """
        The ID of the listener that is associated with the endpoint group.
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Endpoint Group names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the endpoint group.
        """
        return pulumi.get(self, "status")


class AwaitableGetEndpointGroupsResult(GetEndpointGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointGroupsResult(
            accelerator_id=self.accelerator_id,
            endpoint_group_type=self.endpoint_group_type,
            groups=self.groups,
            id=self.id,
            ids=self.ids,
            listener_id=self.listener_id,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status)


def get_endpoint_groups(accelerator_id: Optional[str] = None,
                        endpoint_group_type: Optional[str] = None,
                        ids: Optional[Sequence[str]] = None,
                        listener_id: Optional[str] = None,
                        name_regex: Optional[str] = None,
                        output_file: Optional[str] = None,
                        status: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointGroupsResult:
    """
    This data source provides the Global Accelerator (GA) Endpoint Groups of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.113.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    region = config.get("region")
    if region is None:
        region = "cn-hangzhou"
    name = config.get("name")
    if name is None:
        name = "tf-example"
    default = alicloud.ga.get_accelerators(status="active")
    default_bandwidth_package = alicloud.ga.BandwidthPackage("default",
        bandwidth=100,
        type="Basic",
        bandwidth_type="Basic",
        payment_type="PayAsYouGo",
        billing_type="PayBy95",
        ratio=30,
        bandwidth_package_name=name,
        auto_pay=True,
        auto_use_coupon=True)
    default_bandwidth_package_attachment = alicloud.ga.BandwidthPackageAttachment("default",
        accelerator_id=default.ids[0],
        bandwidth_package_id=default_bandwidth_package.id)
    default_listener = alicloud.ga.Listener("default",
        accelerator_id=default_bandwidth_package_attachment.accelerator_id,
        client_affinity="SOURCE_IP",
        protocol="UDP",
        name=name,
        port_ranges=[{
            "from_port": 60,
            "to_port": 70,
        }])
    default_eip_address = alicloud.ecs.EipAddress("default",
        bandwidth="10",
        internet_charge_type="PayByBandwidth",
        address_name=name)
    default_endpoint_group = alicloud.ga.EndpointGroup("default",
        accelerator_id=default_listener.accelerator_id,
        listener_id=default_listener.id,
        description=name,
        name=name,
        threshold_count=4,
        traffic_percentage=20,
        endpoint_group_region="cn-hangzhou",
        health_check_interval_seconds=3,
        health_check_path="/healthcheck",
        health_check_port=9999,
        health_check_protocol="http",
        port_overrides={
            "endpoint_port": 10,
            "listener_port": 60,
        },
        endpoint_configurations=[{
            "endpoint": default_eip_address.ip_address,
            "type": "PublicIp",
            "weight": 20,
        }])
    default_get_endpoint_groups = alicloud.ga.get_endpoint_groups_output(accelerator_id=default_endpoint_group.accelerator_id,
        ids=[default_endpoint_group.id])
    pulumi.export("firstGaEndpointGroupId", default_get_endpoint_groups.groups[0].id)
    ```


    :param str accelerator_id: The ID of the Global Accelerator instance to which the endpoint group will be added.
    :param str endpoint_group_type: The endpoint group type. Default value: `default`. Valid values: `default`, `virtual`.
    :param Sequence[str] ids: A list of Endpoint Group IDs.
    :param str listener_id: The ID of the listener that is associated with the endpoint group.
    :param str name_regex: A regex string to filter results by Endpoint Group name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the endpoint group. Valid values: `active`, `configuring`, `creating`, `init`.
    """
    __args__ = dict()
    __args__['acceleratorId'] = accelerator_id
    __args__['endpointGroupType'] = endpoint_group_type
    __args__['ids'] = ids
    __args__['listenerId'] = listener_id
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ga/getEndpointGroups:getEndpointGroups', __args__, opts=opts, typ=GetEndpointGroupsResult).value

    return AwaitableGetEndpointGroupsResult(
        accelerator_id=pulumi.get(__ret__, 'accelerator_id'),
        endpoint_group_type=pulumi.get(__ret__, 'endpoint_group_type'),
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        listener_id=pulumi.get(__ret__, 'listener_id'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'))
def get_endpoint_groups_output(accelerator_id: Optional[pulumi.Input[str]] = None,
                               endpoint_group_type: Optional[pulumi.Input[Optional[str]]] = None,
                               ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                               listener_id: Optional[pulumi.Input[Optional[str]]] = None,
                               name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               status: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEndpointGroupsResult]:
    """
    This data source provides the Global Accelerator (GA) Endpoint Groups of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.113.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    region = config.get("region")
    if region is None:
        region = "cn-hangzhou"
    name = config.get("name")
    if name is None:
        name = "tf-example"
    default = alicloud.ga.get_accelerators(status="active")
    default_bandwidth_package = alicloud.ga.BandwidthPackage("default",
        bandwidth=100,
        type="Basic",
        bandwidth_type="Basic",
        payment_type="PayAsYouGo",
        billing_type="PayBy95",
        ratio=30,
        bandwidth_package_name=name,
        auto_pay=True,
        auto_use_coupon=True)
    default_bandwidth_package_attachment = alicloud.ga.BandwidthPackageAttachment("default",
        accelerator_id=default.ids[0],
        bandwidth_package_id=default_bandwidth_package.id)
    default_listener = alicloud.ga.Listener("default",
        accelerator_id=default_bandwidth_package_attachment.accelerator_id,
        client_affinity="SOURCE_IP",
        protocol="UDP",
        name=name,
        port_ranges=[{
            "from_port": 60,
            "to_port": 70,
        }])
    default_eip_address = alicloud.ecs.EipAddress("default",
        bandwidth="10",
        internet_charge_type="PayByBandwidth",
        address_name=name)
    default_endpoint_group = alicloud.ga.EndpointGroup("default",
        accelerator_id=default_listener.accelerator_id,
        listener_id=default_listener.id,
        description=name,
        name=name,
        threshold_count=4,
        traffic_percentage=20,
        endpoint_group_region="cn-hangzhou",
        health_check_interval_seconds=3,
        health_check_path="/healthcheck",
        health_check_port=9999,
        health_check_protocol="http",
        port_overrides={
            "endpoint_port": 10,
            "listener_port": 60,
        },
        endpoint_configurations=[{
            "endpoint": default_eip_address.ip_address,
            "type": "PublicIp",
            "weight": 20,
        }])
    default_get_endpoint_groups = alicloud.ga.get_endpoint_groups_output(accelerator_id=default_endpoint_group.accelerator_id,
        ids=[default_endpoint_group.id])
    pulumi.export("firstGaEndpointGroupId", default_get_endpoint_groups.groups[0].id)
    ```


    :param str accelerator_id: The ID of the Global Accelerator instance to which the endpoint group will be added.
    :param str endpoint_group_type: The endpoint group type. Default value: `default`. Valid values: `default`, `virtual`.
    :param Sequence[str] ids: A list of Endpoint Group IDs.
    :param str listener_id: The ID of the listener that is associated with the endpoint group.
    :param str name_regex: A regex string to filter results by Endpoint Group name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the endpoint group. Valid values: `active`, `configuring`, `creating`, `init`.
    """
    __args__ = dict()
    __args__['acceleratorId'] = accelerator_id
    __args__['endpointGroupType'] = endpoint_group_type
    __args__['ids'] = ids
    __args__['listenerId'] = listener_id
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ga/getEndpointGroups:getEndpointGroups', __args__, opts=opts, typ=GetEndpointGroupsResult)
    return __ret__.apply(lambda __response__: GetEndpointGroupsResult(
        accelerator_id=pulumi.get(__response__, 'accelerator_id'),
        endpoint_group_type=pulumi.get(__response__, 'endpoint_group_type'),
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        listener_id=pulumi.get(__response__, 'listener_id'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EngineNamespaceArgs', 'EngineNamespace']

@pulumi.input_type
class EngineNamespaceArgs:
    def __init__(__self__, *,
                 namespace_show_name: pulumi.Input[str],
                 accept_language: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 namespace_desc: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a EngineNamespace resource.
        :param pulumi.Input[str] namespace_show_name: The name of the Engine Namespace.
        :param pulumi.Input[str] accept_language: The language type of the returned information. Valid values: `zh`, `en`.
        :param pulumi.Input[str] cluster_id: The id of the cluster.It is formatted to `mse-xxxxxxxx`.
        :param pulumi.Input[str] instance_id: The instance id of the cluster. It is formatted to `mse-cn-xxxxxxxxxxx`.Available since v1.232.0.
        :param pulumi.Input[str] namespace_desc: The description of the namespace.
               
               **NOTE:** You must set `cluster_id` or `instance_id` or both.
        :param pulumi.Input[str] namespace_id: The id of Namespace.
        """
        pulumi.set(__self__, "namespace_show_name", namespace_show_name)
        if accept_language is not None:
            pulumi.set(__self__, "accept_language", accept_language)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if namespace_desc is not None:
            pulumi.set(__self__, "namespace_desc", namespace_desc)
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)

    @property
    @pulumi.getter(name="namespaceShowName")
    def namespace_show_name(self) -> pulumi.Input[str]:
        """
        The name of the Engine Namespace.
        """
        return pulumi.get(self, "namespace_show_name")

    @namespace_show_name.setter
    def namespace_show_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace_show_name", value)

    @property
    @pulumi.getter(name="acceptLanguage")
    def accept_language(self) -> Optional[pulumi.Input[str]]:
        """
        The language type of the returned information. Valid values: `zh`, `en`.
        """
        return pulumi.get(self, "accept_language")

    @accept_language.setter
    def accept_language(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "accept_language", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the cluster.It is formatted to `mse-xxxxxxxx`.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The instance id of the cluster. It is formatted to `mse-cn-xxxxxxxxxxx`.Available since v1.232.0.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="namespaceDesc")
    def namespace_desc(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the namespace.

        **NOTE:** You must set `cluster_id` or `instance_id` or both.
        """
        return pulumi.get(self, "namespace_desc")

    @namespace_desc.setter
    def namespace_desc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_desc", value)

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of Namespace.
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_id", value)


@pulumi.input_type
class _EngineNamespaceState:
    def __init__(__self__, *,
                 accept_language: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 namespace_desc: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[str]] = None,
                 namespace_show_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EngineNamespace resources.
        :param pulumi.Input[str] accept_language: The language type of the returned information. Valid values: `zh`, `en`.
        :param pulumi.Input[str] cluster_id: The id of the cluster.It is formatted to `mse-xxxxxxxx`.
        :param pulumi.Input[str] instance_id: The instance id of the cluster. It is formatted to `mse-cn-xxxxxxxxxxx`.Available since v1.232.0.
        :param pulumi.Input[str] namespace_desc: The description of the namespace.
               
               **NOTE:** You must set `cluster_id` or `instance_id` or both.
        :param pulumi.Input[str] namespace_id: The id of Namespace.
        :param pulumi.Input[str] namespace_show_name: The name of the Engine Namespace.
        """
        if accept_language is not None:
            pulumi.set(__self__, "accept_language", accept_language)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if namespace_desc is not None:
            pulumi.set(__self__, "namespace_desc", namespace_desc)
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)
        if namespace_show_name is not None:
            pulumi.set(__self__, "namespace_show_name", namespace_show_name)

    @property
    @pulumi.getter(name="acceptLanguage")
    def accept_language(self) -> Optional[pulumi.Input[str]]:
        """
        The language type of the returned information. Valid values: `zh`, `en`.
        """
        return pulumi.get(self, "accept_language")

    @accept_language.setter
    def accept_language(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "accept_language", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the cluster.It is formatted to `mse-xxxxxxxx`.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The instance id of the cluster. It is formatted to `mse-cn-xxxxxxxxxxx`.Available since v1.232.0.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="namespaceDesc")
    def namespace_desc(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the namespace.

        **NOTE:** You must set `cluster_id` or `instance_id` or both.
        """
        return pulumi.get(self, "namespace_desc")

    @namespace_desc.setter
    def namespace_desc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_desc", value)

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of Namespace.
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_id", value)

    @property
    @pulumi.getter(name="namespaceShowName")
    def namespace_show_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Engine Namespace.
        """
        return pulumi.get(self, "namespace_show_name")

    @namespace_show_name.setter
    def namespace_show_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_show_name", value)


class EngineNamespace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accept_language: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 namespace_desc: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[str]] = None,
                 namespace_show_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Microservice Engine (MSE) Engine Namespace resource.

        For information about Microservice Engine (MSE) Engine Namespace and how to use it, see [What is Engine Namespace](https://www.alibabacloud.com/help/en/mse/developer-reference/api-mse-2019-05-31-createenginenamespace).

        > **NOTE:** Available since v1.166.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.get_zones(available_resource_creation="VSwitch")
        example_network = alicloud.vpc.Network("example",
            vpc_name="terraform-example",
            cidr_block="172.17.3.0/24")
        example_switch = alicloud.vpc.Switch("example",
            vswitch_name="terraform-example",
            cidr_block="172.17.3.0/24",
            vpc_id=example_network.id,
            zone_id=example.zones[0].id)
        example_cluster = alicloud.mse.Cluster("example",
            cluster_specification="MSE_SC_1_2_60_c",
            cluster_type="Nacos-Ans",
            cluster_version="NACOS_2_0_0",
            instance_count=3,
            net_type="privatenet",
            pub_network_flow="1",
            connection_type="slb",
            cluster_alias_name="terraform-example",
            mse_version="mse_pro",
            vswitch_id=example_switch.id,
            vpc_id=example_network.id)
        example_engine_namespace = alicloud.mse.EngineNamespace("example",
            instance_id=example_cluster.id,
            namespace_show_name="terraform-example",
            namespace_id="terraform-example",
            namespace_desc="description")
        ```

        ## Import

        Microservice Engine (MSE) Engine Namespace can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:mse/engineNamespace:EngineNamespace example <instance_id>:<namespace_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accept_language: The language type of the returned information. Valid values: `zh`, `en`.
        :param pulumi.Input[str] cluster_id: The id of the cluster.It is formatted to `mse-xxxxxxxx`.
        :param pulumi.Input[str] instance_id: The instance id of the cluster. It is formatted to `mse-cn-xxxxxxxxxxx`.Available since v1.232.0.
        :param pulumi.Input[str] namespace_desc: The description of the namespace.
               
               **NOTE:** You must set `cluster_id` or `instance_id` or both.
        :param pulumi.Input[str] namespace_id: The id of Namespace.
        :param pulumi.Input[str] namespace_show_name: The name of the Engine Namespace.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EngineNamespaceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Microservice Engine (MSE) Engine Namespace resource.

        For information about Microservice Engine (MSE) Engine Namespace and how to use it, see [What is Engine Namespace](https://www.alibabacloud.com/help/en/mse/developer-reference/api-mse-2019-05-31-createenginenamespace).

        > **NOTE:** Available since v1.166.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.get_zones(available_resource_creation="VSwitch")
        example_network = alicloud.vpc.Network("example",
            vpc_name="terraform-example",
            cidr_block="172.17.3.0/24")
        example_switch = alicloud.vpc.Switch("example",
            vswitch_name="terraform-example",
            cidr_block="172.17.3.0/24",
            vpc_id=example_network.id,
            zone_id=example.zones[0].id)
        example_cluster = alicloud.mse.Cluster("example",
            cluster_specification="MSE_SC_1_2_60_c",
            cluster_type="Nacos-Ans",
            cluster_version="NACOS_2_0_0",
            instance_count=3,
            net_type="privatenet",
            pub_network_flow="1",
            connection_type="slb",
            cluster_alias_name="terraform-example",
            mse_version="mse_pro",
            vswitch_id=example_switch.id,
            vpc_id=example_network.id)
        example_engine_namespace = alicloud.mse.EngineNamespace("example",
            instance_id=example_cluster.id,
            namespace_show_name="terraform-example",
            namespace_id="terraform-example",
            namespace_desc="description")
        ```

        ## Import

        Microservice Engine (MSE) Engine Namespace can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:mse/engineNamespace:EngineNamespace example <instance_id>:<namespace_id>
        ```

        :param str resource_name: The name of the resource.
        :param EngineNamespaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EngineNamespaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accept_language: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 namespace_desc: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[str]] = None,
                 namespace_show_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EngineNamespaceArgs.__new__(EngineNamespaceArgs)

            __props__.__dict__["accept_language"] = accept_language
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["namespace_desc"] = namespace_desc
            __props__.__dict__["namespace_id"] = namespace_id
            if namespace_show_name is None and not opts.urn:
                raise TypeError("Missing required property 'namespace_show_name'")
            __props__.__dict__["namespace_show_name"] = namespace_show_name
        super(EngineNamespace, __self__).__init__(
            'alicloud:mse/engineNamespace:EngineNamespace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accept_language: Optional[pulumi.Input[str]] = None,
            cluster_id: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            namespace_desc: Optional[pulumi.Input[str]] = None,
            namespace_id: Optional[pulumi.Input[str]] = None,
            namespace_show_name: Optional[pulumi.Input[str]] = None) -> 'EngineNamespace':
        """
        Get an existing EngineNamespace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accept_language: The language type of the returned information. Valid values: `zh`, `en`.
        :param pulumi.Input[str] cluster_id: The id of the cluster.It is formatted to `mse-xxxxxxxx`.
        :param pulumi.Input[str] instance_id: The instance id of the cluster. It is formatted to `mse-cn-xxxxxxxxxxx`.Available since v1.232.0.
        :param pulumi.Input[str] namespace_desc: The description of the namespace.
               
               **NOTE:** You must set `cluster_id` or `instance_id` or both.
        :param pulumi.Input[str] namespace_id: The id of Namespace.
        :param pulumi.Input[str] namespace_show_name: The name of the Engine Namespace.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EngineNamespaceState.__new__(_EngineNamespaceState)

        __props__.__dict__["accept_language"] = accept_language
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["namespace_desc"] = namespace_desc
        __props__.__dict__["namespace_id"] = namespace_id
        __props__.__dict__["namespace_show_name"] = namespace_show_name
        return EngineNamespace(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="acceptLanguage")
    def accept_language(self) -> pulumi.Output[Optional[str]]:
        """
        The language type of the returned information. Valid values: `zh`, `en`.
        """
        return pulumi.get(self, "accept_language")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[str]:
        """
        The id of the cluster.It is formatted to `mse-xxxxxxxx`.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The instance id of the cluster. It is formatted to `mse-cn-xxxxxxxxxxx`.Available since v1.232.0.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="namespaceDesc")
    def namespace_desc(self) -> pulumi.Output[str]:
        """
        The description of the namespace.

        **NOTE:** You must set `cluster_id` or `instance_id` or both.
        """
        return pulumi.get(self, "namespace_desc")

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> pulumi.Output[str]:
        """
        The id of Namespace.
        """
        return pulumi.get(self, "namespace_id")

    @property
    @pulumi.getter(name="namespaceShowName")
    def namespace_show_name(self) -> pulumi.Output[str]:
        """
        The name of the Engine Namespace.
        """
        return pulumi.get(self, "namespace_show_name")

